# <img src="assets/logo.png" width="50px"> Romeo

<a href="https://pypi.python.org/pypi/romeo"><img src="https://img.shields.io/pypi/v/romeo.svg" /></a>
<a href="https://travis-ci.com/brendalf/romeo"><img src="https://img.shields.io/travis/brendalf/romeo.svg" /></a>
<a href="https://romeo-cli.readthedocs.io/en/latest/?badge=latest"><img src="https://readthedocs.org/projects/romeo-cli/badge/?version=latest" /></a>
<a href="https://pyup.io/repos/github/brendalf/romeo/"><img src="https://pyup.io/repos/github/brendalf/romeo/shield.svg" /></a>

Romeo is a CLI for managing data science projects.

## Documentation
> Work in Progress  

Read the docs in https://romeo-cli.readthedocs.io.

## Installation
> Work in Progress   

`pip install romeo`

## Features
> Work in Progress
* [ ] init          -> creates a new datascience project based on template folder
* [ ] clean         -> clean temporary files from project folder
* [ ] train         -> train a model based on romeo.json
* [ ] score         -> scores a model based on romeo.json
* [ ] models 
    * [ ] list      -> list models registreds
    * [ ] add       -> register a new model
    * [ ] rm        -> remove a model
* [ ] logs          -> show log information about training and scoring.

## Contributions
Feel free to contribute.  
Don't know how to contribute? Read the [CONTRIBUTING.md](https://github.com/brendalf/romeo/blob/master/CONTRIBUTING.md)

## License 
Free software: GNU General Public License v3
